Rename to slothfs.

Change-Id: I001ba50ec4d1f62a0faf54df50e589d7525f7a74
diff --git a/README.md b/README.md
index ff94cb9..e46734f 100644
--- a/README.md
+++ b/README.md
@@ -1,6 +1,6 @@
 
-This is a FUSE filesystem that provides light-weight, read-only checkouts of Git
-repositories. It is intended for use with Android.
+This is a FUSE filesystem that provides light-weight, lazily downloaded,
+read-only checkouts of Git repositories. It is intended for use with Android.
 
 
 How to use
@@ -8,28 +8,28 @@
 
 To start the file system:
 
-    go install github.com/google/gitfs/cmd/gitfs-multifs
+    go install github.com/google/slothfs/cmd/slothfs-multifs
     mkdir /tmp/mnt
-    gitfs-multifs -gitiles https://android.googlesource.com/  /tmp/mnt &
+    slothfs-multifs -gitiles https://android.googlesource.com/  /tmp/mnt &
 
 To create a workspace "ws" corresponding to the latest manifest version
 
-    go install github.com/google/gitfs/cmd/gitfs-expand-manifest
-    gitfs-expand-manifest --gitiles https://android.googlesource.com/ \
+    go install github.com/google/slothfs/cmd/slothfs-expand-manifest
+    slothfs-expand-manifest --gitiles https://android.googlesource.com/ \
        > /tmp/m.xml &&
     ln -s /tmp/m.xml /tmp/mnt/config/ws
 
 To populate a checkout
 
-    go install github.com/google/gitfs/cmd/gitfs-populate
+    go install github.com/google/slothfs/cmd/slothfs-populate
     mkdir -p checkout/frameworks
     cd checkout/frameworks
     git clone https://android.googlesource.com/platform/frameworks/base
     cd ../
-    gitfs-populate -ro /tmp/mnt/ws .
+    slothfs-populate -ro /tmp/mnt/ws .
 
 The filesystem daemon uses an on-disk cache, which by default is stored under
-~/.cache/gitfs
+~/.cache/slothfs
 
 
 Configuring
diff --git a/all.bash b/all.bash
index 5b8973a..30ba013 100644
--- a/all.bash
+++ b/all.bash
@@ -19,14 +19,14 @@
 gitiles \
 cache \
 fs \
-cmd/gitfs-expand-manifest \
-cmd/gitfs-multifs \
-cmd/gitfs-manifestfs \
-cmd/gitfs-populate \
-cmd/gitfs-gitilesfs \
-cmd/gitfs-deref-manifest \
+cmd/slothfs-expand-manifest \
+cmd/slothfs-multifs \
+cmd/slothfs-manifestfs \
+cmd/slothfs-populate \
+cmd/slothfs-gitilesfs \
+cmd/slothfs-deref-manifest \
   ; do
-  p=github.com/google/gitfs/${sub}
+  p=github.com/google/slothfs/${sub}
   go clean $p
   go test $p
   go install $p
diff --git a/cache/gitcache.go b/cache/gitcache.go
index b79c9f1..e1e2604 100644
--- a/cache/gitcache.go
+++ b/cache/gitcache.go
@@ -42,7 +42,7 @@
 func newGitCache(baseDir string) (*gitCache, error) {
 	c := gitCache{
 		dir:    filepath.Join(baseDir),
-		logDir: filepath.Join(baseDir, "gitfs-logs"),
+		logDir: filepath.Join(baseDir, "slothfs-logs"),
 	}
 	if err := os.MkdirAll(c.logDir, 0700); err != nil {
 		return nil, err
diff --git a/cache/treecache.go b/cache/treecache.go
index 754a448..286ce07 100644
--- a/cache/treecache.go
+++ b/cache/treecache.go
@@ -21,7 +21,7 @@
 	"os"
 	"path/filepath"
 
-	"github.com/google/gitfs/gitiles"
+	"github.com/google/slothfs/gitiles"
 	git "github.com/libgit2/git2go"
 )
 
diff --git a/cache/treecache_test.go b/cache/treecache_test.go
index 1de119a..ba307c6 100644
--- a/cache/treecache_test.go
+++ b/cache/treecache_test.go
@@ -20,7 +20,7 @@
 	"reflect"
 	"testing"
 
-	"github.com/google/gitfs/gitiles"
+	"github.com/google/slothfs/gitiles"
 	git "github.com/libgit2/git2go"
 )
 
diff --git a/cmd/gitfs-expand-manifest/main.go b/cmd/slothfs-expand-manifest/main.go
similarity index 97%
rename from cmd/gitfs-expand-manifest/main.go
rename to cmd/slothfs-expand-manifest/main.go
index 5eaf508..a9ace1d 100644
--- a/cmd/gitfs-expand-manifest/main.go
+++ b/cmd/slothfs-expand-manifest/main.go
@@ -20,8 +20,8 @@
 	"log"
 	"os"
 
-	"github.com/google/gitfs/gitiles"
-	"github.com/google/gitfs/manifest"
+	"github.com/google/slothfs/gitiles"
+	"github.com/google/slothfs/manifest"
 )
 
 func main() {
diff --git a/cmd/gitfs-gitilesfs/main.go b/cmd/slothfs-gitilesfs/main.go
similarity index 93%
rename from cmd/gitfs-gitilesfs/main.go
rename to cmd/slothfs-gitilesfs/main.go
index 078a1a0..628b7f1 100644
--- a/cmd/gitfs-gitilesfs/main.go
+++ b/cmd/slothfs-gitilesfs/main.go
@@ -21,9 +21,9 @@
 	"path/filepath"
 	"time"
 
-	"github.com/google/gitfs/cache"
-	"github.com/google/gitfs/fs"
-	"github.com/google/gitfs/gitiles"
+	"github.com/google/slothfs/cache"
+	"github.com/google/slothfs/fs"
+	"github.com/google/slothfs/gitiles"
 	"github.com/hanwen/go-fuse/fuse/nodefs"
 )
 
@@ -32,7 +32,7 @@
 	branch := flag.String("branch", "master", "branch name")
 	repo := flag.String("repo", "", "repository name")
 	debug := flag.Bool("debug", false, "print debug info")
-	cacheDir := flag.String("cache", filepath.Join(os.Getenv("HOME"), ".cache", "gitfs"), "cache dir")
+	cacheDir := flag.String("cache", filepath.Join(os.Getenv("HOME"), ".cache", "slothfs"), "cache dir")
 	flag.Parse()
 
 	if *cacheDir == "" {
diff --git a/cmd/gitfs-manifestfs/main.go b/cmd/slothfs-manifestfs/main.go
similarity index 93%
rename from cmd/gitfs-manifestfs/main.go
rename to cmd/slothfs-manifestfs/main.go
index a02ab22..1b3199a 100644
--- a/cmd/gitfs-manifestfs/main.go
+++ b/cmd/slothfs-manifestfs/main.go
@@ -22,17 +22,17 @@
 	"path/filepath"
 	"time"
 
-	"github.com/google/gitfs/cache"
-	"github.com/google/gitfs/fs"
-	"github.com/google/gitfs/gitiles"
-	"github.com/google/gitfs/manifest"
+	"github.com/google/slothfs/cache"
+	"github.com/google/slothfs/fs"
+	"github.com/google/slothfs/gitiles"
+	"github.com/google/slothfs/manifest"
 	"github.com/hanwen/go-fuse/fuse/nodefs"
 )
 
 func main() {
 	manifestPath := flag.String("manifest", "", "expanded manifest file path")
 	gitilesURL := flag.String("gitiles", "", "gitiles URL. If unset, derive from manifest location.")
-	cacheDir := flag.String("cache", filepath.Join(os.Getenv("HOME"), ".cache", "gitfs"), "cache dir")
+	cacheDir := flag.String("cache", filepath.Join(os.Getenv("HOME"), ".cache", "slothfs"), "cache dir")
 	debug := flag.Bool("debug", false, "print debug info")
 	config := flag.String("config", "", "JSON file configuring what repositories should be cloned.")
 	flag.Parse()
diff --git a/cmd/gitfs-multifs/main.go b/cmd/slothfs-multifs/main.go
similarity index 93%
rename from cmd/gitfs-multifs/main.go
rename to cmd/slothfs-multifs/main.go
index 23d9c48..31b076b 100644
--- a/cmd/gitfs-multifs/main.go
+++ b/cmd/slothfs-multifs/main.go
@@ -22,15 +22,15 @@
 	"path/filepath"
 	"time"
 
-	"github.com/google/gitfs/cache"
-	"github.com/google/gitfs/fs"
-	"github.com/google/gitfs/gitiles"
+	"github.com/google/slothfs/cache"
+	"github.com/google/slothfs/fs"
+	"github.com/google/slothfs/gitiles"
 	"github.com/hanwen/go-fuse/fuse/nodefs"
 )
 
 func main() {
 	gitilesURL := flag.String("gitiles", "", "gitiles URL. If unset, derive from manifest location.")
-	cacheDir := flag.String("cache", filepath.Join(os.Getenv("HOME"), ".cache", "gitfs"), "cache dir")
+	cacheDir := flag.String("cache", filepath.Join(os.Getenv("HOME"), ".cache", "slothfs"), "cache dir")
 	debug := flag.Bool("debug", false, "print debug info")
 	config := flag.String("config", "", "JSON file configuring what repositories should be cloned.")
 	flag.Parse()
diff --git a/cmd/gitfs-populate/main.go b/cmd/slothfs-populate/main.go
similarity index 98%
rename from cmd/gitfs-populate/main.go
rename to cmd/slothfs-populate/main.go
index 2b01c58..a336ea7 100644
--- a/cmd/gitfs-populate/main.go
+++ b/cmd/slothfs-populate/main.go
@@ -319,7 +319,7 @@
 }
 
 func main() {
-	mount := flag.String("ro", "", "path to gitfs-multifs mount.")
+	mount := flag.String("ro", "", "path to slothfs-multifs mount.")
 	flag.Parse()
 
 	dir := "."
diff --git a/cmd/gitfs-populate/main_test.go b/cmd/slothfs-populate/main_test.go
similarity index 100%
rename from cmd/gitfs-populate/main_test.go
rename to cmd/slothfs-populate/main_test.go
diff --git a/design.md b/design.md
index cf51acb..bab20c5 100644
--- a/design.md
+++ b/design.md
@@ -152,7 +152,7 @@
 
 * FUSE daemon:
    * Add support for serving trees based on Gitiles JSON data
-   * Add support for lazily cloning .git repositories in gitfs
+   * Add support for lazily cloning .git repositories
    * Add support for chtimes
    * Add support for sharing blobs
    * Add support for a CAS
diff --git a/fs/api.go b/fs/api.go
index 87361ae..6bfb0d4 100644
--- a/fs/api.go
+++ b/fs/api.go
@@ -17,7 +17,7 @@
 import (
 	"regexp"
 
-	"github.com/google/gitfs/manifest"
+	"github.com/google/slothfs/manifest"
 )
 
 // CloneOption configures for which files we should trigger a git clone.
diff --git a/fs/gitilesfs.go b/fs/gitilesfs.go
index 809f0a0..b192c02 100644
--- a/fs/gitilesfs.go
+++ b/fs/gitilesfs.go
@@ -23,8 +23,8 @@
 	"syscall"
 	"time"
 
-	"github.com/google/gitfs/cache"
-	"github.com/google/gitfs/gitiles"
+	"github.com/google/slothfs/cache"
+	"github.com/google/slothfs/gitiles"
 	"github.com/hanwen/go-fuse/fuse"
 	"github.com/hanwen/go-fuse/fuse/nodefs"
 	git "github.com/libgit2/git2go"
diff --git a/fs/gitilesfs_test.go b/fs/gitilesfs_test.go
index c568e35..728b31e 100644
--- a/fs/gitilesfs_test.go
+++ b/fs/gitilesfs_test.go
@@ -31,9 +31,9 @@
 	"testing"
 	"time"
 
-	"github.com/google/gitfs/cache"
-	"github.com/google/gitfs/gitiles"
-	"github.com/google/gitfs/manifest"
+	"github.com/google/slothfs/cache"
+	"github.com/google/slothfs/gitiles"
+	"github.com/google/slothfs/manifest"
 	"github.com/hanwen/go-fuse/fuse"
 	"github.com/hanwen/go-fuse/fuse/nodefs"
 )
diff --git a/fs/manifestfs.go b/fs/manifestfs.go
index fe57340..9a51150 100644
--- a/fs/manifestfs.go
+++ b/fs/manifestfs.go
@@ -20,9 +20,9 @@
 	"path/filepath"
 	"strings"
 
-	"github.com/google/gitfs/cache"
-	"github.com/google/gitfs/gitiles"
-	"github.com/google/gitfs/manifest"
+	"github.com/google/slothfs/cache"
+	"github.com/google/slothfs/gitiles"
+	"github.com/google/slothfs/manifest"
 	"github.com/hanwen/go-fuse/fuse"
 	"github.com/hanwen/go-fuse/fuse/nodefs"
 	git "github.com/libgit2/git2go"
diff --git a/fs/multifs.go b/fs/multifs.go
index c8edfcb..5711e22 100644
--- a/fs/multifs.go
+++ b/fs/multifs.go
@@ -19,9 +19,9 @@
 	"log"
 	"path/filepath"
 
-	"github.com/google/gitfs/cache"
-	"github.com/google/gitfs/gitiles"
-	"github.com/google/gitfs/manifest"
+	"github.com/google/slothfs/cache"
+	"github.com/google/slothfs/gitiles"
+	"github.com/google/slothfs/manifest"
 	"github.com/hanwen/go-fuse/fuse"
 	"github.com/hanwen/go-fuse/fuse/nodefs"
 )
diff --git a/cmd/gitfs-deref-manifest/main.go b/cmd/slothfs-deref-manifest/main.go
similarity index 93%
rename from cmd/gitfs-deref-manifest/main.go
rename to cmd/slothfs-deref-manifest/main.go
index f1dd238..dd50a66 100644
--- a/cmd/gitfs-deref-manifest/main.go
+++ b/cmd/slothfs-deref-manifest/main.go
@@ -13,7 +13,7 @@
 // limitations under the License.
 
 // This program creates a manifest file with revisions filled in from
 // a normal repo checkout. This can be used for comparing gitfs and
 // actual repo checkouts.
 package main
 
@@ -23,7 +23,7 @@
 	"os"
 	"path/filepath"
 
-	"github.com/google/gitfs/manifest"
+	"github.com/google/slothfs/manifest"
 	"github.com/libgit2/git2go"
 )
 
@@ -13,7 +13,7 @@
 
 // This program creates a manifest file with revisions filled in from
-// a normal repo checkout. This can be used for comparing gitfs and
+// a normal repo checkout. This can be used for comparing slothfs and
 // actual repo checkouts.
 package main